@@ -22,11 +22,11 @@ function start_mgrd {
     python ./nuhemgrd.py 
   fi
 
-  EPLASTLOG=$(find /var/log/nuhemgrd.log -printf '%p %Cs\n' | cut -d' ' -f2)  
-  EPNOW=$(date +%s)
-  if [ $(( $EPNOW - 60  )) -ge $EPLASTLOG ]; then
-     echo "$(date) Requesting restart, NOW: $EPNOW LAST: $EPLASTLOG" >> /tmp/pulla.txt
-     ./restartmgr.sh
+  if [ -f /opt/home/concheck ]; then
+    if [ "$(cat /opt/home/concheck)" == "0" ];then
+	 echo "$(date) Requesting restart: $(date +%s)" >> /tmp/pulla.txt
+        ./restartmgr.sh
+    fi
   fi
 }
 
@@ -50,5 +50,4 @@ do
   sleep 10
 done
 
-
 exit 0
