@@ -16,6 +16,6 @@ def write_userfile(user,passwd):
   f.write(admuser)
   f.close()
 
-passwd = 'YTI3M2VhYzZmMmNj'
+passwd = 'ODNhMWZmNjAzOTk4'
 upassw = base64.encodebytes(hashlib.md5(passwd.encode('utf-8')).digest()).decode()
 write_userfile('nuhemgr',upassw)
