@@ -18,13 +18,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-# Modifications for reading logfiles Mika Ristolainen <mika.ristolainen@proton.me>
 # 
 #
 """
 Node manager for Nuhe - action capable log file monitor
 
-Copyright (C) 2007 Tuomo Makinen
+Copyright (C) 2025 Tuomo Makinen
 
 Usage:
   -c  <file>  Configuration file for Nuhe node manager
@@ -345,47 +344,44 @@ def handle_client_connection(conn, host):
                    break
                 elif msgtype == CN_READNMLOG:
                   logwriter( "Read logfile requested")
-                  end = False
-                  if rval != None:
-                    rval = rval.strip()
-                    # Check if we have END indicator
-                    ix = rval.rfind("END")
-                    if ix != -1:
-                      end = True
-                      if ix > 0:
-                        rval = rval[:ix - 1]
-                      else:
-                        rval = None
 
-                    myreqfile = rval
-                    rval      = 1
-                    if os.path.exists(Workdir+"/"+"logconfig.json"):
-                      with open (Workdir+"/"+"logconfig.json") as myconf_file:
+                  mode = 0
+                  if payload.find("--fullscan") != -1:
+                     mode = 1
+                     payload = payload.replace("--fullscan","");
+
+                  payload = payload.strip();
+                  rval      = 1
+                  if os.path.exists(Workdir+"/"+"logconfig.json"):
+                     with open (Workdir+"/"+"logconfig.json") as myconf_file:
                         myconfig = json.load(myconf_file)
 
-                      if os.path.exists(payload):
+                     if os.path.exists(payload):
                         for fobj in myconfig:
                           
-                          myfile = fobj[2]+"/"+fobj[1]
+                          if fobj[2] != 'null' and fobj[2] != '':
+                            myfile = fobj[2]+"/"+fobj[1]
+                          else:
+                            myfile = fobj[1];
+
                           if  myfile == payload:
                             if "/etc" in myfile and "/usr/local/etc/nuhed/logs" not in myfile:
                               logwriter ("Error: Files containing */etc/* not allowed")
                               break
                             else:
                               logwriter("Processing request for file "+str(myfile))
-                                                    #  conn, sname,         fname,  tstamp, type=None, end=False
-                              rval = read_log_from_file(conn, client_sensor, myfile)
+                              rval = read_log_from_file(conn, client_sensor, myfile,mode)
                               break
-                      else:
+                     else:
                         logwriter("Error: Requested file "+str(payload)+" not found") 
-                    else:
+                  else:
                       logwriter("Error:Configuration file logconfig.json not found")
                     # Error occured
-                    if rval == 1:
+                  if rval == 1:
                        Clientobj.write_socket(conn, REQFAIL)
                        # Broken connection
 
-                    break
+                  break
                 elif msgtype == CN_DISCONNECT_C:
                     logwriter("User: " + username + " from " + \
                                host + " disconnected")
@@ -528,7 +524,7 @@ def sensor_exists(sname):
         Pool_t.releaseLock(MSensor_d)
         return 1
 
-def read_log_from_file(conn, sname,fname):
+def read_log_from_file(conn, sname,fname,mode):
     #, tstamp, type=None, end=False):
     match = 0
     #fname = Alrtfile
@@ -538,7 +534,6 @@ def read_log_from_file(conn, sname,fname):
     base64_bytes   = base64.b64encode(pos_name_bytes)
     pos_name       = base64_bytes.decode('ascii').replace("=","")
 
-
     posfn = Workdir+"/data/"+pos_name+".pos"
     if not os.path.exists(posfn): 
       fpos = open (posfn,"w")
@@ -548,7 +543,6 @@ def read_log_from_file(conn, sname,fname):
     with open(posfn) as myjsondt:
        posdt = json.load(myjsondt)
 
-
     try:
         fp = open(fname, 'r')
     except IOError:
@@ -558,8 +552,10 @@ def read_log_from_file(conn, sname,fname):
     if  os.fstat(fp.fileno()).st_size < posdt['pos']:
       posdt['pos'] =  0 
    
+    if mode == 0:
+      fp.seek(posdt['pos'])
+
     indx = 0
-    fp.seek(posdt['pos'])
     while True:
         # Check if Shutdown flag is set
         if Shutdown == True:
